aboutsummaryrefslogtreecommitdiff
path: root/lisp/mastodon-tl.el
diff options
context:
space:
mode:
authormarty hiatt <martianhiatus@disroot.org>2024-11-01 15:05:44 +0100
committermarty hiatt <martianhiatus@disroot.org>2024-11-01 15:06:24 +0100
commit1ba949586efbbcd50be9f341cfc3f8b9c591fb3b (patch)
treed99001976eb0f6df4b88c730cb97bbb21240874b /lisp/mastodon-tl.el
parentbabb3a1adf7dbc2c458c65d841e758aafaabd298 (diff)
tl: improve ctrl flow in --spoiler + --toot. FIX #579
Diffstat (limited to 'lisp/mastodon-tl.el')
-rw-r--r--lisp/mastodon-tl.el38
1 files changed, 17 insertions, 21 deletions
diff --git a/lisp/mastodon-tl.el b/lisp/mastodon-tl.el
index b655bec..595f0cf 100644
--- a/lisp/mastodon-tl.el
+++ b/lisp/mastodon-tl.el
@@ -1275,25 +1275,22 @@ FILTER is a string to use as a filter warning spoiler instead."
(cw (mastodon-tl--set-face message 'mastodon-cw-face)))
(concat
cw
- (propertize (mastodon-tl--content toot)
- 'invisible
- (if filter
- t
- (let ((cust mastodon-tl--expand-content-warnings))
- (cond ((eq t cust)
- nil)
- ((eq nil cust)
- t)
- ((eq 'server cust)
- (unless (eq t
- ;; If something goes wrong reading prefs,
- ;; just return nil so CWs show by default.
- (condition-case nil
- (mastodon-profile--get-preferences-pref
- 'reading:expand:spoilers)
- (error nil)))
- t)))))
- 'mastodon-content-warning-body t))))
+ (propertize
+ (mastodon-tl--content toot)
+ 'invisible
+ (or filter ;; filters = invis
+ (let ((cust mastodon-tl--expand-content-warnings))
+ (if (not (eq 'server cust))
+ (not cust) ;; opp to setting
+ ;; respect server setting:
+ (not
+ ;; If something goes wrong reading prefs,
+ ;; just return nil so CWs show by default.
+ (condition-case nil
+ (mastodon-profile--get-preferences-pref
+ 'reading:expand:spoilers)
+ (error nil))))))
+ 'mastodon-content-warning-body t))))
;;; MEDIA
@@ -1793,8 +1790,7 @@ NO-CW means treat content warnings as unfolded."
(mastodon-tl--content toot)))))
;; If any filters are "hide", then we hide,
;; even though item may also have a "warn" filter:
- (if (and filtered (assoc "hide" filters))
- nil ;; no insert
+ (unless (and filtered (assoc "hide" filters)) ;; no insert
(mastodon-tl--insert-status
toot
(mastodon-tl--clean-tabs-and-nl spoiler-or-content)